import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Box } from '@primer/react';
import { useEffect } from 'react';
import { BaseNotebook, useKernelId, useNotebookModel, } from './BaseNotebook';
import './Notebook.css';
/**
 * Simple notebook component without adapter and stores.
 *
 * Notes:
 * - You must provide the appropriate service manager
 * - You can specified the kernel id to use; if it is not defined or empty and startDefaultKernel is true, a new kernel will be started.
 */
export function SimpleNotebook(props) {
    const { CellSidebar, Toolbar, cellSidebarMargin = 120, children, collaborationServer, commandRegistry, extensions, height = '100vh', maxHeight = '100vh', id, nbformat, nbgrader = false, onNotebookModelChanged, onSessionConnection, path, readonly = false, serviceManager, startDefaultKernel = false, url, } = props;
    const kernelId = useKernelId({
        requestedKernelId: props.kernelId,
        kernels: serviceManager.kernels,
        startDefaultKernel,
    });
    const model = useNotebookModel({
        collaborationServer,
        nbformat,
        readonly,
        url,
    });
    useEffect(() => {
        onNotebookModelChanged?.(model);
    }, [model, onNotebookModelChanged]);
    return (_jsxs(Box, { style: { height, width: '100%', position: 'relative' }, id: "dla-Jupyter-Notebook", children: [Toolbar && _jsx(Toolbar, { notebookId: id }), _jsxs(Box, { className: "dla-Box-Notebook", sx: {
                    height,
                    maxHeight,
                    width: '100%',
                    overflowY: 'hidden',
                    '& .datalayer-NotebookPanel-header': {
                        minHeight: '50px',
                    },
                    '& .jp-Notebook': {
                        flex: '1 1 auto !important',
                        height: '100%',
                        overflowY: 'scroll',
                    },
                    '& .jp-NotebookPanel': {
                        height: '100% !important',
                        width: '100% !important',
                    },
                    '& .jp-Toolbar': {
                        display: 'none',
                        zIndex: 0,
                    },
                    '& .jp-Toolbar .jp-HTMLSelect.jp-DefaultStyle select': {
                        fontSize: '14px',
                    },
                    '& .jp-Toolbar > .jp-Toolbar-responsive-opener': {
                        display: 'none',
                    },
                    '& .jp-Toolbar-kernelName': {
                        display: 'none',
                    },
                    '& .jp-Cell': {
                        width: `calc(100% - ${cellSidebarMargin}px)`,
                    },
                    '& .jp-Notebook-footer': {
                        width: `calc(100% - ${cellSidebarMargin + 82}px)`,
                    },
                    '& .jp-Cell .jp-CellHeader': {
                        position: 'absolute',
                        top: '-5px',
                        left: `${cellSidebarMargin + 10}px`,
                        height: 'auto',
                    },
                    '& .jp-Cell .dla-CellSidebar-Container': {
                        padding: '4px 8px',
                        width: `${cellSidebarMargin + 10}px`,
                        marginLeft: 'auto',
                    },
                    '& .jp-CodeMirrorEditor': {
                        cursor: 'text !important',
                    },
                    '.dla-Box-Notebook': {
                        position: 'relative',
                    },
                }, children: [children, model && serviceManager && (_jsx(BaseNotebook, { CellSidebar: CellSidebar, commandRegistry: commandRegistry, id: id, extensions: extensions, model: model, nbgrader: nbgrader, serviceManager: serviceManager, kernelId: kernelId, onSessionConnectionChanged: onSessionConnection, path: path }))] })] }));
}
//# sourceMappingURL=SimpleNotebook.js.map